@@ -1,10 +1,8 @@
 """Useful Functions with Built-in Library"""
 
 import os
-import sys
 import html
 import time
-import threading
 import traceback
 import urllib.parse
 import urllib.request
@@ -33,18 +31,29 @@ def log(*value):
 
 def check(obj, patt='.*'):
     import re
+    import sys
+    import inspect
     patt = re.compile(patt)
     print('\nobj:', obj)
-    for key in filter(patt.fullmatch, dir(obj)):
+    for key in sorted(dir(obj)):
         attr = getattr(obj, key)
-        print('\nkey:', key)
-        if not callable(attr):
-            print('value:', attr)
-        else:
-            try:
-                print('value call:', attr())
-            except TypeError as e:
-                print('value callable:', attr, 'TypeError:', e)
+        try:
+            key += str(inspect.signature(attr))
+        except (TypeError, ValueError):
+            pass
+        if patt.fullmatch(key):
+            key = '.' + key
+            if not callable(attr):
+                result = repr(attr)
+                key += ' = '
+            else:
+                try:
+                    result = repr(attr())
+                    key += ' = '
+                except Exception:
+                    result = ''
+            print(key, end='')
+            print(result, file=sys.stderr)
 
 
 fps_n = -1
@@ -68,6 +77,7 @@ def fps():
 # ---------------------------------------------------------------------------
 
 
+stem = lambda p: os.path.splitext(os.path.basename(p))[0]
 select = lambda path: os.popen('explorer /select, "%s"' % os.path.abspath(path))
 
 
